==> huaweicloudsdkkoomessage-3.1.58-py2.py3-none-any.whl: huaweicloudsdkkoomessage/v1/model/delete_template_material_request_body.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class DeleteTemplateMaterialRequestBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'material_ids': 'list[str]'
    }

    attribute_map = {
        'material_ids': 'material_ids'
    }

    def __init__(self, material_ids=None):
        """DeleteTemplateMaterialRequestBody

        The model defined in huaweicloud sdk

        :param material_ids: 模板素材ID数组。
        :type material_ids: list[str]
        """
        
        

        self._material_ids = None
        self.discriminator = None

        self.material_ids = material_ids

    @property
    def material_ids(self):
        """Gets the material_ids of this DeleteTemplateMaterialRequestBody.

        模板素材ID数组。

        :return: The material_ids of this DeleteTemplateMaterialRequestBody.
        :rtype: list[str]
        """
        return self._material_ids

    @material_ids.setter
    def material_ids(self, material_ids):
        """Sets the material_ids of this DeleteTemplateMaterialRequestBody.

        模板素材ID数组。

        :param material_ids: The material_ids of this DeleteTemplateMaterialRequestBody.
        :type material_ids: list[str]
        """
        self._material_ids = material_ids

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeleteTemplateMaterialRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkkoomessage-3.1.148-py2.py3-none-any.whl: huaweicloudsdkkoomessage/v1/model/delete_template_material_request_body.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class DeleteTemplateMaterialRequestBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'material_ids': 'list[str]'
    }

    attribute_map = {
        'material_ids': 'material_ids'
    }

    def __init__(self, material_ids=None):
        r"""DeleteTemplateMaterialRequestBody

        The model defined in huaweicloud sdk

        :param material_ids: 模板素材ID数组。
        :type material_ids: list[str]
        """
        
        

        self._material_ids = None
        self.discriminator = None

        self.material_ids = material_ids

    @property
    def material_ids(self):
        r"""Gets the material_ids of this DeleteTemplateMaterialRequestBody.

        模板素材ID数组。

        :return: The material_ids of this DeleteTemplateMaterialRequestBody.
        :rtype: list[str]
        """
        return self._material_ids

    @material_ids.setter
    def material_ids(self, material_ids):
        r"""Sets the material_ids of this DeleteTemplateMaterialRequestBody.

        模板素材ID数组。

        :param material_ids: The material_ids of this DeleteTemplateMaterialRequestBody.
        :type material_ids: list[str]
        """
        self._material_ids = material_ids

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeleteTemplateMaterialRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
